@@ -18,6 +18,7 @@ pub(crate) struct AsyncOpsState {
     async_ops: HashMap<u64, Rc<RefCell<AsyncOp>>>,
     ids: Ids,
     new_async_ops: Vec<AsyncOpRef>,
+    dropped_events: u64,
 }
 
 #[derive(Debug, Copy, Clone)]
@@ -67,7 +68,7 @@ impl Default for SortBy {
 }
 
 impl SortBy {
-    pub fn sort(&self, now: SystemTime, ops: &mut Vec<Weak<RefCell<AsyncOp>>>) {
+    pub fn sort(&self, now: SystemTime, ops: &mut [Weak<RefCell<AsyncOp>>]) {
         match self {
             Self::Aid => ops.sort_unstable_by_key(|ao| ao.upgrade().map(|a| a.borrow().num)),
             Self::Task => ops.sort_unstable_by_key(|ao| ao.upgrade().map(|a| a.borrow().task_id())),
@@ -201,6 +202,8 @@ impl AsyncOpsState {
                 }
             }
         }
+
+        self.dropped_events += update.dropped_events;
     }
 
     pub(crate) fn retain_active(&mut self, now: SystemTime, retain_for: Duration) {
@@ -211,12 +214,16 @@ impl AsyncOpsState {
                 .stats
                 .dropped_at
                 .map(|d| {
-                    let dropped_for = now.duration_since(d).unwrap();
+                    let dropped_for = now.duration_since(d).unwrap_or_default();
                     retain_for > dropped_for
                 })
                 .unwrap_or(true)
         })
     }
+
+    pub(crate) fn dropped_events(&self) -> u64 {
+        self.dropped_events
+    }
 }
 
 impl AsyncOp {
@@ -247,14 +254,15 @@ impl AsyncOp {
     pub(crate) fn total(&self, since: SystemTime) -> Duration {
         self.stats
             .total
-            .unwrap_or_else(|| since.duration_since(self.stats.created_at).unwrap())
+            .or_else(|| since.duration_since(self.stats.created_at).ok())
+            .unwrap_or_default()
     }
 
     pub(crate) fn busy(&self, since: SystemTime) -> Duration {
         if let (Some(last_poll_started), None) =
             (self.stats.last_poll_started, self.stats.last_poll_ended)
         {
-            let current_time_in_poll = since.duration_since(last_poll_started).unwrap();
+            let current_time_in_poll = since.duration_since(last_poll_started).unwrap_or_default();
             return self.stats.busy + current_time_in_poll;
         }
         self.stats.busy
@@ -263,7 +271,8 @@ impl AsyncOp {
     pub(crate) fn idle(&self, since: SystemTime) -> Duration {
         self.stats
             .idle
-            .unwrap_or_else(|| self.total(since) - self.busy(since))
+            .or_else(|| self.total(since).checked_sub(self.busy(since)))
+            .unwrap_or_default()
     }
 
     pub(crate) fn total_polls(&self) -> u64 {
@@ -309,11 +318,11 @@ impl AsyncOpStats {
             .unwrap();
 
         let dropped_at: Option<SystemTime> = pb.dropped_at.map(|v| v.try_into().unwrap());
-        let total = dropped_at.map(|d| d.duration_since(created_at).unwrap());
+        let total = dropped_at.map(|d| d.duration_since(created_at).unwrap_or_default());
 
         let poll_stats = pb.poll_stats.expect("task should have poll stats");
         let busy = poll_stats.busy_time.map(pb_duration).unwrap_or_default();
-        let idle = total.map(|total| total - busy);
+        let idle = total.map(|total| total.checked_sub(busy).unwrap_or_default());
         let formatted_attributes = Attribute::make_formatted(styles, &mut attributes);
         let task_id = pb.task_id.map(|id| task_ids.id_for(id.id));
         let task_id_str = strings.string(
