@@ -16,6 +16,7 @@ pub(crate) struct ResourcesState {
     resources: HashMap<u64, Rc<RefCell<Resource>>>,
     pub(crate) ids: Ids,
     new_resources: Vec<ResourceRef>,
+    dropped_events: u64,
 }
 
 #[derive(Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd)]
@@ -74,7 +75,7 @@ impl Default for SortBy {
 }
 
 impl SortBy {
-    pub fn sort(&self, now: SystemTime, resources: &mut Vec<Weak<RefCell<Resource>>>) {
+    pub fn sort(&self, now: SystemTime, resources: &mut [Weak<RefCell<Resource>>]) {
         match self {
             Self::Rid => resources
                 .sort_unstable_by_key(|resource| resource.upgrade().map(|r| r.borrow().num)),
@@ -225,6 +226,8 @@ impl ResourcesState {
             Some((num, resource))
         });
 
+        self.dropped_events += update.dropped_events;
+
         self.resources.extend(new_resources);
 
         for (span_id, stats) in stats_update {
@@ -246,12 +249,16 @@ impl ResourcesState {
                 .stats
                 .dropped_at
                 .map(|d| {
-                    let dropped_for = now.duration_since(d).unwrap();
+                    let dropped_for = now.duration_since(d).unwrap_or_default();
                     retain_for > dropped_for
                 })
                 .unwrap_or(true)
         })
     }
+
+    pub(crate) fn dropped_events(&self) -> u64 {
+        self.dropped_events
+    }
 }
 
 impl Resource {
@@ -296,9 +303,11 @@ impl Resource {
     }
 
     pub(crate) fn total(&self, since: SystemTime) -> Duration {
-        self.stats
-            .total
-            .unwrap_or_else(|| since.duration_since(self.stats.created_at).unwrap())
+        self.stats.total.unwrap_or_else(|| {
+            since
+                .duration_since(self.stats.created_at)
+                .unwrap_or_default()
+        })
     }
 
     pub(crate) fn dropped(&self) -> bool {
@@ -338,7 +347,7 @@ impl ResourceStats {
             .try_into()
             .unwrap();
         let dropped_at: Option<SystemTime> = pb.dropped_at.map(|v| v.try_into().unwrap());
-        let total = dropped_at.map(|d| d.duration_since(created_at).unwrap());
+        let total = dropped_at.map(|d| d.duration_since(created_at).unwrap_or_default());
 
         Self {
             created_at,
