@@ -4,7 +4,7 @@ pub use tui::{backend::CrosstermBackend, Terminal};
 
 pub fn init_crossterm() -> color_eyre::Result<(Terminal<CrosstermBackend<io::Stdout>>, OnShutdown)>
 {
-    use crossterm::terminal::{self, EnterAlternateScreen, LeaveAlternateScreen};
+    use crossterm::terminal::{self, EnterAlternateScreen};
     terminal::enable_raw_mode().wrap_err("Failed to enable crossterm raw mode")?;
 
     let mut stdout = std::io::stdout();
@@ -13,18 +13,21 @@ pub fn init_crossterm() -> color_eyre::Result<(Terminal<CrosstermBackend<io::Std
     let backend = CrosstermBackend::new(io::stdout());
     let term = Terminal::new(backend).wrap_err("Failed to create crossterm terminal")?;
 
-    let cleanup = OnShutdown::new(|| {
-        // Be a good terminal citizen...
-        let mut stdout = std::io::stdout();
-        crossterm::execute!(stdout, LeaveAlternateScreen)
-            .wrap_err("Failed to disable crossterm alternate screen")?;
-        terminal::disable_raw_mode().wrap_err("Failed to enable crossterm raw mode")?;
-        Ok(())
-    });
+    let cleanup = OnShutdown::new(exit_crossterm);
 
     Ok((term, cleanup))
 }
 
+pub(crate) fn exit_crossterm() -> color_eyre::Result<()> {
+    use crossterm::terminal::{self, LeaveAlternateScreen};
+    // Be a good terminal citizen...
+    let mut stdout = std::io::stdout();
+    crossterm::execute!(stdout, LeaveAlternateScreen)
+        .wrap_err("Failed to disable crossterm alternate screen")?;
+    terminal::disable_raw_mode().wrap_err("Failed to enable crossterm raw mode")?;
+    Ok(())
+}
+
 pub struct OnShutdown {
     action: fn() -> color_eyre::Result<()>,
 }
