@@ -33,8 +33,8 @@ pub struct View {
     /// details view), we want to leave the task list's state the way we left it
     /// --- e.g., if the user previously selected a particular sorting, we want
     /// it to remain sorted that way when we return to it.
-    tasks_list: TableListState<TasksTable>,
-    resources_list: TableListState<ResourcesTable>,
+    tasks_list: TableListState<TasksTable, 11>,
+    resources_list: TableListState<ResourcesTable, 9>,
     state: ViewState,
     pub(crate) styles: Styles,
 }
@@ -87,8 +87,8 @@ impl View {
     pub fn new(styles: Styles) -> Self {
         Self {
             state: ViewState::TasksList,
-            tasks_list: TableListState::<TasksTable>::default(),
-            resources_list: TableListState::<ResourcesTable>::default(),
+            tasks_list: TableListState::<TasksTable, 11>::default(),
+            resources_list: TableListState::<ResourcesTable, 9>::default(),
             styles,
         }
     }
